@@ -5,7 +5,7 @@ use Carp;
 use Scalar::Util qw/ blessed /;
 extends 'Catalyst::View::Email';
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 $VERSION = eval $VERSION;
 =head1 NAME
 
@@ -54,7 +54,6 @@ the template instead of the body and forwarding to your Email::Template view:
         $c->stash->{email} = {
             to          => 'jshirley@gmail.com',
             cc          => 'abraxxa@cpan.org',
-            bcc         => 'hidden@secret.com hidden2@foobar.com',
             from        => 'no-reply@foobar.com',
             subject     => 'I am a Catalyst generated email',
             template    => 'test.tt',
@@ -292,9 +291,12 @@ around 'process' => sub {
 
     # single part api
     elsif ( $c->stash->{$stash_key}->{template} ) {
+        my $part_args = { template => $c->stash->{$stash_key}->{template} };
+        if (my $ctype = $c->stash->{$stash_key}->{content_type}) {
+            $part_args->{content_type} = $ctype;
+        }
         push @parts,
-          $self->generate_part( $c,
-            { template => $c->stash->{$stash_key}->{template}, } );
+          $self->generate_part( $c, $part_args );
     }
 
     delete $c->stash->{$stash_key}->{body};
